@@ -10,16 +10,16 @@ bool Map::v_block(const Point &p) const {
     return v[p.y() - 1][p.x() - 1];
 }
 
-bool Map::set_h_block(const Point &p) {
+bool Map::set_h_block(const Point &p, bool set) {
     if (p.x() == 0 || p.y() == 0) return false;
-    if (h_block(p)) return false;
-    h[p.y() - 1][p.x() - 1] = true;
+    if (set && h_block(p)) return false;
+    h[p.y() - 1][p.x() - 1] = set;
     return true;
 }
 
-bool Map::set_v_block(const Point &p) {
+bool Map::set_v_block(const Point &p, bool set) {
     if (p.x() == 0 || p.y() == 0) return false;
-    if (v_block(p)) return false;
-    v[p.y() - 1][p.x() - 1] = true;
+    if (set && v_block(p)) return false;
+    v[p.y() - 1][p.x() - 1] = set;
     return true;
 }
\ No newline at end of file
